@@ -1,5 +1,6 @@
 from collections import namedtuple
 
+import imageio
 import numpy as np
 
 from voxypy.numpy_vox_io.models import Vox
@@ -121,7 +122,6 @@ class Entity:
         return s
 
     def set_palette_from_file(self, filename):
-        import imageio
         new_palette = np.array(imageio.imread(filename), dtype=int)
         new_palette = [Color(*c) for row in new_palette for c in row]
         self.set_palette(new_palette)
@@ -220,3 +220,8 @@ class Entity:
     def layers(self):
         for _z in range(self.z):
             yield self.get_layer(_z)
+
+    def nonzero(self):
+        hits = np.where(self._voxels != 0)
+        hits = list(zip(*hits))
+        return hits
